@@ -205,9 +205,10 @@ setMethod("over", signature("SpatialPoints", "SpatialPixelsDataFrame"),
 
 setMethod("over", signature("Spatial", "Spatial"),  # catch remaining:
 	function(x, y, returnList = FALSE, fn = NULL, ...) {
+        warning("No rgeos support in sp from October 2023;\nsee https://r-spatial.org/r/2023/05/15/evolution4.html")
 		.Deprecated("sf::st_intersects or sf::aggregate")
-    	if (!requireNamespace("rgeos", quietly = TRUE))
-			stop("package rgeos is required for additional over methods")
+#    	if (!requireNamespace("rgeos", quietly = TRUE))
+			stop("use sf or terra functions")
 		if (is(x, "SpatialMultiPoints") || is(y, "SpatialMultiPoints"))
 			overMultiPoints(x, y, returnList = returnList, fn = fn, ...)
 		else
@@ -229,12 +230,13 @@ overMultiPoints = function(x, y, returnList, fn, ...) {
 			y = as(y, "SpatialPoints")
 		dimnames(y@coords)[[1]] = attr(y@coords, "groupIndex") # rgeos abuse
 	}
-   	if (!requireNamespace("rgeos", quietly = TRUE))
-		stop("package rgeos is required for additional over methods")
-	if ("data" %in% slotNames(y))
-		rgeos::overGeomGeomDF(x, y, returnList = returnList, fn = fn, ...)
-	else
-		rgeos::overGeomGeom(x, y, returnList = returnList, fn = fn, ...)
+#   	if (!requireNamespace("rgeos", quietly = TRUE))
+		stop("use sf or terra functions")
+#	if ("data" %in% slotNames(y))
+#		rgeos::overGeomGeomDF(x, y, returnList = returnList, fn = fn, ...)
+#	else
+#		rgeos::overGeomGeom(x, y, returnList = returnList, fn = fn, ...)
+
 }
 
 .index2list = function(x, returnList) {
